Installation of the cb_key_stroke module
========================================


Pip Installation
----------------


**cb_key_stroke** can easily be installed from the python package index https://pypi.org/project/cb-key-stroke/ by using pip:

.. tab:: Linux

   .. code-block:: bash

      pip3 install ./cb_key_stroke-<release>-py3-none-any.whl

      or

      pip3 install cb-key-stroke

.. tab:: Max OSX

   .. code-block:: bash

      pip3 install ./cb_key_stroke-<release>-py3-none-any.whl

      or

      pip3 install ./cb-key-stroke

.. tab:: Windows

   .. code-block:: bash

      python3 -m pip install cb_key_stroke-<release>-py3-none-any.whl

      or

      python3 -m pip install cb-key-stroke
